#
# spec file for package perl-Perl-Tidy
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Perl-Tidy
Version:        20200110
Release:        bp153.1.17
#Upstream: GPL-1.0-or-later
%define cpan_name Perl-Tidy
Summary:        Parses and beautifies perl source
License:        GPL-2.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SH/SHANCOCK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
This module makes the functionality of the perltidy utility available to
perl scripts. Any or all of the input parameters may be omitted, in which
case the @ARGV array will be used to provide input parameters as described
in the perltidy(1) man page.

For example, the perltidy script is basically just this:

    use Perl::Tidy;
    Perl::Tidy::perltidy();

The call to *perltidy* returns a scalar *$error_flag* which is TRUE if an
error caused premature termination, and FALSE if the process ran to normal
completion. Additional discuss of errors is contained below in the ERROR
HANDLING section.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc BUGS.md CHANGES.md docs examples pm2pl README.md
%license COPYING

%changelog
* Fri Jan 10 2020 <timueller+perl@suse.de>
- updated to 20200110
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES.md
  [#]# 2020 01 10
  - This release adds a flag to control the feature RT#130394 (allow short nested blocks)
    introduced in the previous release.  Unfortunately that feature breaks
    RPerl installations, so a control flag has been introduced and that feature is now
    off by default.  The flag is:
  - -one-line-block-nesting=n, or -olbn=n, where n is an integer as follows:
  - olbn=0 break nested one-line blocks into multiple lines [new DEFAULT]
  - olbn=1 stable; keep existing nested-one line blocks intact [previous DEFAULT]
    For example, consider this input line:
    foreach (@list) { if ($_ eq $asked_for) { last } ++$found }
    The new default behavior (-olbn=0), and behavior prior to version 20191203, is to break it into multiple lines:
    foreach (@list) {
    if ( $_ eq $asked_for ) { last }
    ++$found;
    }
    To keep nested one-line blocks such as this on a single line you can add the parameter -olbn=1.
  - Fixed issue RT#131288: parse error for un-prototyped constant function without parenthesized
    call parameters followed by ternary.
  - Fixed issue RT#131360, installation documentation.  Added a note that the binary
    'perltidy' comes with the Perl::Tidy module. They can both normally be installed with
    'cpanm Perl::Tidy'
* Wed Dec  4 2019 <timueller+perl@suse.de>
- updated to 20191203
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES.md
  [#]# 2019 12 03
  - Fixed issue RT#131115: -bli option not working correctly.
    Closing braces were not indented in some cases due to a glitch
    introduced in version 20181120.
  - Fixed issue RT#130394: Allow short nested blocks.  Given the following
    $factorial = sub { reduce { $a * $b } 1 .. 11 };
    Previous versions would always break the sub block because it
    contains another block (the reduce block).  The fix keeps
    short one-line blocks such as this intact.
  - Implement issue RT#130640: Allow different subroutine keywords.
    Added a flag --sub-alias-list=s or -sal=s, where s is a string with
    one or more aliases for 'sub', separated by spaces or commas.
    For example,
    perltidy -sal='method fun'
    will cause the perltidy to treat the words 'method' and 'fun' to be
    treated the same as if they were 'sub'.
  - Added flag --space-prototype-paren=i, or -spp=i, to control spacing
    before the opening paren of a prototype, where i=0, 1, or 2:
    i=0 no space
    i=1 follow input [current and default]
    i=2 always space
    Previously, perltidy always followed the input.
    For example, given the following input
    sub usage();
    The result will be:
    sub usage();    # i=0 [no space]
    sub usage();    # i=1 [default; follows input]
    sub usage ();   # i=2 [space]
  - Fixed issue git#16, minor vertical alignment issue.
  - Fixed issue git#10, minor conflict of -wn and -ce
  - Improved some vertical alignments involving two lines.
* Mon Sep 16 2019 <timueller+perl@suse.de>
- updated to 20190915
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES.md
  [#]# 2019 09 15
  - fixed issue RT#130344: false warning "operator in print statement"
    for "use lib".
  - fixed issue RT#130304: standard error output should include filename.
    When perltidy error messages are directed to the standard error output
    with -se or --standard-error-output, the message lines now have a prefix
    'filename:' for clarification in case multiple files
    are processed, where 'filename' is the name of the input file.  If
    input is from the standard input the displayed filename is '<stdin>',
    and if it is from a data structure then displayed filename
    is '<source_stream>'.
  - implement issue RT#130425: check mode.  A new flag '--assert-tidy'
    will cause an error message if the output script is not identical to
    the input script. For completeness, the opposite flag '--assert-untidy'
    has also been added.  The next item, RT#130297, insures that the script
    will exit with a non-zero exit flag if the assertion fails.
  - fixed issue RT#130297; the perltidy script now exits with a nonzero exit
    status if it wrote to the standard error output. Prevously only fatal
    run errors produced a non-zero exit flag. Now, even non-fatal messages
    requested with the -w flag will cause a non-zero exit flag.  The exit
    flag now has these values:
    0 = no errors
    1 = perltidy could not run to completion due to errors
    2 = perltidy ran to completion with error messages
  - added warning message for RT#130008, which warns of conflicting input
    parameters -iob and -bom or -boc.
  - fixed RT#129850; concerning a space between a closing block brace and
    opening bracket or brace, as occurs before the '[' in this line:
    my @addunix = map { File::Spec::Unix->catfile( @ROOT, @$_ ) } ['b'];
    Formerly, any space was removed. Now it is optional, and the output will
    follow the input.
  - fixed issue git#13, needless trailing whitespace in error message
  - fixed issue git#9: if the -ce (--cuddled-else) flag is used,
    do not try to form new one line blocks for a block type
    specified with -cbl, particularly map, sort, grep
  - iteration speedup for unchanged code.  Previously, when iterations were
    requested, at least two formatting passes were made. Now just a single pass
    is made if the formatted code is identical to the input code.
  - some improved vertical alignments
* Sat Jun  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 20190601
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES.md
  [#]# 2019 06 01
  - rt #128477: Prevent inconsistent owner/group and setuid/setgid bits.
    In the -b (--backup-and-modify-in-place) mode, an attempt is made to set ownership
    of the output file equal to the input file, if they differ.
    In all cases, if the final output file ownership differs from input file, any setuid/setgid bits are cleared.
  - Added option -bom  (--break-at-old-method-breakpoints) by
    merrillymeredith which preserves breakpoints of method chains. Modified to also handle a cuddled call style.
  - Merged patch to fix Windows EOL translation error with UTF-8 written by
    Ron Ivy. This update prevents automatic conversion to 'DOS' CRLF line
    endings.  Also, Windows system testing at the appveyor site is working again.
  - RT #128280, added flag --one-line-block-semicolons=n (-olbs=n)
    to control semicolons in one-line blocks.  The values of n are:
    n=0 means no semicolons termininating simple one-line blocks
    n=1 means stable; do not change from input file [DEFAULT and current]
    n=2 means always add semicolons in one-line blocks
    The current behavior corresponds to the default n=1.
  - RT #128216, Minor update to prevent inserting unwanted blank line at
    indentation level change.  This should not change existing scripts.
  - RT #81852: Improved indentation when quoted word (qw) lists are
    nested within other containers using the --weld-nested (-wn) flag.
    The example given previously (below) is now closer to what it would
    be with a simple list instead of qw:
    [#] perltidy -wn
    use_all_ok( qw{
    PPI
    PPI::Tokenizer
    PPI::Lexer
    PPI::Dumper
    PPI::Find
    PPI::Normal
    PPI::Util
    PPI::Cache
    } );
  - RT#12764, introduced new feature allowing placement of blanks around
    sequences of selected keywords. This can be activated with the -kgb*
    series of parameters described in the manual.
  - Rewrote vertical algnment module.  It is better at finding
    patterns in complex code. For example,
  OLD:
    /^-std$/ && do { $std       = 1;     next; };
    /^--$/   && do { @link_args = @argv; last; };
    /^-I(.*)/ && do { $path = $1 || shift @argv; next; };
  NEW:
    /^-std$/  && do { $std       = 1;                 next; };
    /^--$/    && do { @link_args = @argv;             last; };
    /^-I(.*)/ && do { $path      = $1 || shift @argv; next; };
  - Add repository URLs to META files
  - RT #118553, "leave only one newline at end of file". This option was not
    added because of undesirable side effects, but a new filter script
    was added which can do this, "examples/delete_ending_blank_lines.pl".
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 20181120
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES.md
* Wed Feb 21 2018 coolo@suse.com
- updated to 20180220
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES
    2018 02 20
  - RT #124469, #124494, perltidy often making empty files.  The previous had
    an index error causing it to fail, particularly in version 5.18 of Perl.
    Please avoid version 20180219.
* Mon Feb 19 2018 coolo@suse.com
- updated to 20180219
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES
    2018 02 19
  - RT #79947, cuddled-else generalization. A new flag -cb provides
    'cuddled-else' type formatting for an arbitrary type of block chain. The
    default is try-catch-finally, but this can be modified with the
    parameter -cbl.
  - Fixed RT #124298: add space after ! operator without breaking !! secret
    operator
  - RT #123749: numerous minor improvements to the -wn flag were made.
  - Fixed a problem with convergence tests in which iterations were stopping
    prematurely.
  - Here doc targets for <<~ type here-docs may now have leading whitespace.
  - Fixed RT #124354. The '-indent-only' flag was not working correctly in the
    previous release. A bug in version 20180101 caused extra blank lines
    to be output.
  - Issue RT #124114. Some improvements were made in vertical alignment
    involving 'fat commas'.
* Mon Jan  1 2018 coolo@suse.com
- updated to 20180101
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES
    2018 01 01
  - Added new flag -wn (--weld-nested-containers) which addresses these issues:
    RT #123749: Problem with promises;
    RT #119970: opening token stacking strange behavior;
    RT #81853: Can't stack block braces
    This option causes closely nested pairs of opening and closing containers
    to be "welded" together and essentially be formatted as a single unit,
    with just one level of indentation.
    Since this is a new flag it is set to be "off" by default but it has given
    excellent results in testing.
    EXAMPLE 1, multiple blocks, default formatting:
    do {
    {
    next if $x == $y;    # do something here
    }
    } until $x++ > $z;
    perltidy -wn
    do { {
    next if $x == $y;
    } } until $x++ > $z;
    EXAMPLE 2, three levels of wrapped function calls, default formatting:
    p(
    em(
    conjug(
    translate( param('verb') ), param('tense'),
    param('person')
    )
    )
    );
    [#] perltidy -wn
    p( em( conjug(
    translate( param('verb') ),
    param('tense'), param('person')
    ) ) );
    [#] EXAMPLE 3, chained method calls, default formatting:
    get('http://mojolicious.org')->then(
    sub {
    my $mojo = shift;
    say $mojo->res->code;
    return get('http://metacpan.org');
    }
    )->then(
    sub {
    my $cpan = shift;
    say $cpan->res->code;
    }
    )->catch(
    sub {
    my $err = shift;
    warn "Something went wrong: $err";
    }
    )->wait;
    [#] perltidy -wn
    get('http://mojolicious.org')->then( sub {
    my $mojo = shift;
    say $mojo->res->code;
    return get('http://metacpan.org');
    } )->then( sub {
    my $cpan = shift;
    say $cpan->res->code;
    } )->catch( sub {
    my $err = shift;
    warn "Something went wrong: $err";
    } )->wait;
  - Fixed RT #114359: Missparsing of "print $x ** 0.5;
  - Deactivated the --check-syntax flag for better security.  It will be
    ignored if set.
  - Corrected minimum perl version from 5.004 to 5.008 based on perlver
    report.  The change is required for coding involving wide characters.
  - For certain severe errors, the source file will be copied directly to the
    output without formatting. These include ending in a quote, ending in a
    here doc, and encountering an unidentified character.
* Thu Dec 14 2017 coolo@suse.com
- updated to 20171214
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES
    2017 12 14
  - RT #123749, partial fix.  "Continuation indentation" is removed from lines
    with leading closing parens which are part of a call chain.
    For example, the call to pack() is is now outdented to the starting
    indentation in the following experession:
    [#] OLD
    $mw->Button(
  - text    => "New Document",
  - command => \&new_document
    )->pack(
  - side   => 'bottom',
  - anchor => 'e'
    );
    [#] NEW
    $mw->Button(
  - text    => "New Document",
  - command => \&new_document
    )->pack(
  - side   => 'bottom',
  - anchor => 'e'
    );
    This modification improves readability of complex expressions, especially
    when the user uses the same value for continuation indentation (-ci=n) and
    normal indentation (-i=n).  Perltidy was already programmed to
    do this but a minor bug was preventing it.
  - RT #123774, added flag to control space between a backslash and a single or
    double quote, requested by Robert Rothenberg.  The issue is that lines like
    $str1=\"string1";
    $str2=\'string2';
    confuse syntax highlighters unless a space is left between the backslash and
    the quote.
    The new flag to control this is -sbq=n (--space-backslash-quote=n),
    where n=0 means no space, n=1 means follow existing code, n=2 means always
    space.  The default is n=1, meaning that a space will be retained if there
    is one in the source code.
  - Fixed RT #123492, support added for indented here doc operator <<~ added
    in v5.26.  Thanks to Chris Weyl for the report.
  - Fixed docs; --closing-side-comment-list-string should have been just
  - -closing-side-comment-list.  Thanks to F.Li.
  - Added patch RT #122030] Perl::Tidy sometimes does not call binmode.
    Thanks to Irilis Aelae.
  - Fixed RT #121959, PERLTIDY doesn't honor the 'three dot' notation for
    locating a config file using environment variables.  Thanks to John
    Wittkowski.
  - Minor improvements to formatting, in which some additional vertical
    aligmnemt is done. Thanks to Keith Neargarder.
  - RT #119588.  Vertical alignment is no longer done for // operator.
* Thu May 25 2017 coolo@suse.com
- updated to 20170521
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES
    2017 05 21
  - Fixed debian #862667: failure to check for perltidy.ERR deletion can lead
    to overwriting abritrary files by symlink attack. Perltidy was continuing
    to write files after an unlink failure.  Thanks to Don Armstrong
    for a patch.
  - Fixed RT #116344, perltidy fails on certain anonymous hash references:
    in the following code snippet the '?' was misparsed as a pattern
    delimiter rather than a ternary operator.
    return ref {} ? 1 : 0;
  - Fixed RT #113792: misparsing of a fat comma (=>) right after
    the __END__ or __DATA__ tokens.  These keywords were getting
    incorrectly quoted by the following => operator.
  - Fixed RT #118558. Custom Getopt::Long configuration breaks parsing
    of perltidyrc.  Perltidy was resetting the users configuration too soon.
  - Fixed RT #119140, failure to parse double diamond operator.  Code to
    handle this new operator has been added.
  - Fixed RT #120968.  Fixed problem where -enc=utf8 didn't work
    with --backup-and-modify-in-place. Thanks to Heinz Knutzen for this patch.
  - Fixed minor formatting issue where one-line blocks for subs with signatures
    were unnecesarily broken
  - RT #32905, patch to fix utf-8 error when output was STDOUT.
  - RT #79947, improved spacing of try/catch/finally blocks. Thanks to qsimpleq
    for a patch.
  - Fixed #114909, Anonymous subs with signatures and prototypes misparsed as
    broken ternaries, in which a statement such as this was not being parsed
    correctly:
    return sub ( $fh, $out ) : prototype(*$) { ... }
  - Implemented RT #113689, option to introduces spaces after an opening block
    brace and before a closing block brace. Four new optional controls are
    added. The first two define the minimum number of blank lines to be
    inserted
  - blao=i or --blank-lines-after-opening-block=i
  - blbc=i or --blank-lines-before-closing-block=i
    where i is an integer, the number of lines (the default is 0).
    The second two define the types of blocks to which the first two apply
  - blaol=s or --blank-lines-after-opening-block-list=s
  - blbcl=s or --blank-lines-before-closing-block-list=s
    where s is a string of possible block keywords (default is just 'sub',
    meaning a named subroutine).
    For more information please see the documentation.
  - The method for specifying block types for certain input parameters has
    been generalized to distinguish between normal named subroutines and
    anonymous subs.  The keyword for normal subroutines remains 'sub', and
    the new keyword for anonymous subs is 'asub'.
  - Minor documentation changes. The BUGS sections now have a link
    to CPAN where most open bugs and issues can be reviewed and bug reports
    can be submitted.  The information in the AUTHOR and CREDITS sections of
    the man pages have been removed from the man pages to streamline the
    documentation. This information is still in the source code.
* Tue Mar  8 2016 coolo@suse.com
- updated to 20160302
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES
    2016 03 02
  - RT #112534. Corrected a minor problem in which an unwanted newline
    was placed before the closing brace of an anonymous sub with
    a signature, if it was in a list.  Thanks to Dmytro Zagashev.
  - Corrected a minor problem in which occasional extra indentation was
    given to the closing brace of an anonymous sub in a list when the -lp
    parameter was set.
    2016 03 01
  - RT #104427. Added support for signatures.
  - RT #111512.  Changed global warning flag $^W = 1 to use warnings;
    Thanks to Dmytro Zagashev.
  - RT #110297, added support for new regexp modifier /n
    Thanks to Dmytro Zagashev.
  - RT #111519.  The -io (--indent-only) and -dac (--delete-all-comments)
    can now both be used in one pass. Thanks to Dmitry Veltishev.
  - Patch to avoid error message with 'catch' used by TryCatch, as in
    catch($err){
    [#] do something
    }
    Thanks to Nick Tonkin.
  - RT #32905, UTF-8 coding is now more robust. Thanks to qsimpleq
    and Dmytro for patches.
  - RT #106885. Added string bitwise operators ^. &. |. ~. ^.= &.= |.=
  - Fixed RT #107832 and #106492, lack of vertical alignment of two lines
    when -boc flag (break at old commas) is set.  This bug was
    inadvertantly introduced in previous bug fix RT #98902.
  - Some common extensions to Perl syntax are handled better.
    In particular, the following snippet is now foratted cleanly:
    method deposit( Num $amount) {
    $self->balance( $self->balance + $amount );
    }
    A new flag -xs (--extended-syntax) was added to enable this, and the default
    is to use -xs.
    In previous versions, and now only when -nxs is set, this snippet of code
    generates the following error message:
    "syntax error at ') {', didn't see one of: case elsif for foreach given if switch unless until when while"
* Sun Aug 23 2015 coolo@suse.com
- updated to 20150815
  see /usr/share/doc/packages/perl-Perl-Tidy/CHANGES
    2015 08 15
  - Fixed RT# 105484, Invalid warning about 'else' in 'switch' statement.  The
    warning happened if a 'case' statement did not use parens.
  - Fixed RT# 101547, misparse of // caused error message.  Also..
  - Fixed RT# 102371, misparse of // caused unwated space in //=
  - Fixed RT# 100871, "silent failure of HTML Output on Windows".
    Changed calls to tempfile() from:
    my ( $fh_tmp, $tmpfile ) = tempfile();
    to have the full path name:
    my ( $fh_tmp, $tmpfile ) = File::Temp::tempfile()
    because of problems in the Windows version reported by Dean Pearce.
  - Fixed RT# 99514, calling the perltidy module multiple times with
    a .perltidyrc file containing the parameter --output-line-ending
    caused a crash.  This was a glitch in the memoization logic.
  - Fixed RT#99961, multiple lines inside a cast block caused unwanted
    continuation indentation.
  - RT# 32905, broken handling of UTF-8 strings.
    A new flag -utf8 causes perltidy assume UTF-8 encoding for input and
    output of an io stream.  Thanks to Sebastian Podjasek for a patch.
    This feature may not work correctly in older versions of Perl.
    It worked in a linux version 5.10.1 but not in a Windows version 5.8.3 (but
    otherwise perltidy ran correctly).
  - Warning files now report perltidy VERSION. Suggested by John Karr.
  - Fixed long flag --nostack-closing-tokens (-nsct has always worked though).
    This was due to a typo.  This also fixed --nostack-opening-tokens to
    behave correctly.  Thanks to Rob Dixon.
* Mon Sep 15 2014 coolo@suse.com
- updated to 20140711
  - Fixed RT #94902: abbreviation parsing in .perltidyrc files was not
    working for multi-line abbreviations.  Thanks to Eric Fung for
    supplying a patch.
  - Fixed RT #95708, misparsing of a hash when the first key was a perl
    keyword, causing a semicolon to be incorrectly added.
  - Fixed RT #94338 for-loop in a parenthesized block-map.  A code block within
    parentheses of a map, sort, or grep function was being mistokenized.  In
    rare cases this could produce in an incorrect error message.  The fix will
    produce some minor formatting changes.  Thanks to Daniel Trizen
    discovering and documenting this.
  - Fixed RT #94354, excess indentation for stacked tokens.  Thanks to
    Colin Williams for supplying a patch.
  - Added support for experimental postfix dereferencing notation introduced in
    perl 5.20. RT #96021.
  - Updated documentation to clarify the behavior of the -io flag
    in response to RT #95709.  You can add -noll or -l=0 to prevent
    long comments from being outdented when -io is used.
  - Added a check to prevent a problem reported in RT #81866, where large
    scripts which had been compressed to a single line could not be formatted
    because of a check for VERSION for MakeMaker. The workaround was to
    use -nvpl, but this shouldn't be necessary now.
  - Fixed RT #96101; Closing brace of anonymous sub in a list was being
    indented.  For example, the closing brace of the anonymous sub below
    will now be lined up with the word 'callback'.  This problem
    occured if there was no comma after the closing brace of the anonymous sub.
    This update may cause minor changes to formatting of code with lists
    of anonymous subs, especially TK code.
* Fri Oct  4 2013 coolo@suse.com
- updated to 20130922
  - Fixed RT #88020. --converge was not working with wide characters.
  - Fixed RT #78156. package NAMESPACE VERSION syntax not accepted.
  - First attempt to fix RT #88588.  INDEX END tag change in pod2html breaks
    perltidy -html. I put in a patch which should work but I don't yet have
    a way of testing it.
* Tue Aug  6 2013 coolo@suse.com
- updated to 20130806
  - Fixed RT #87107, spelling
  - Fixed RT #87502, incorrect of parsing of smartmatch before hash brace
  - Added feature request RT #87330, trim whitespace after POD.
    The flag -trp (--trim-pod) will trim trailing whitespace from lines of POD
* Sat Jul 27 2013 coolo@suse.com
- updated to 20130717
  - Fixed RT #86929, #86930, missing lhs of assignment.
  - Fixed RT #84922, moved pod from Tidy.pm into Tidy.pod
* Sun Jun  9 2013 coolo@suse.com
- updated to 20121207
  - The flag -cab=n or --comma-arrow-breakpoints=n has been generalized
    to give better control over breaking open short containers.  The
    possible values are now:
    n=0 break at all commas after =>
    n=1 stable: break at all commas after => if container is open,
    EXCEPT FOR one-line containers
    n=2 break at all commas after =>, BUT try to form the maximum
    maximum one-line container lengths
    n=3 do not treat commas after => specially at all
    n=4 break everything: like n=0 but also break a short container with
    a => not followed by a comma
    n=5 stable: like n=1 but ALSO break at open one-line containers (default)
    New values n=4 and n=5 have been added to allow short blocks to be
    broken open.  The new default is n=5, stable.  It should more closely
    follow the breaks in the input file, and previously formatted code
    should remain unchanged.  If this causes problems use -cab=1 to recover
    the former behavior.  Thanks to Tony Maszeroski for the suggestion.
    To illustrate the need for the new options, if perltidy is given
    the following code, then the old default (-cab=1) was to close up
    the 'index' container even if it was open in the source.  The new
    default (-cab=5) will keep it open if it was open in the source.
    our $fancypkg = {
    'ALL' => {
    'index' => {
    'key' => 'value',
    },
    'alpine' => {
    'one'   => '+',
    'two'   => '+',
    'three' => '+',
    },
    }
    };
  - New debug flag --memoize (-mem).  This version contains a
    patch supplied by Jonathan Swartz which can significantly speed up
    repeated calls to Perl::Tidy::perltidy in a single process by caching
    the result of parsing the formatting parameters.  A factor of up to 10
    speedup was achieved for masontidy (https://metacpan.org/module/masontidy).
    The memoization patch is on by default but can be deactivated for
    testing with -nmem (or --no-memoize).
* Mon Dec 19 2011 coolo@suse.de
- update to 20101217
  - added new flag -it=n or --iterations=n
  - A configuration file pathname begins with three dots, e.g.
    ".../.perltidyrc", indicates that the file should be searched for starting
    in the current directory and working upwards.
  - Added flag --notidy which disables all formatting and causes the input to be
    copied unchanged.
  - Added prefilters and postfilters in the call to the Tidy.pm module.
  - The starting indentation level of sections of code entabbed with -et=n
    is correctly guessed if it was also produced with the same -et=n flag.  This
    keeps the indentation stable on repeated formatting passes within an editor.
    Thanks to Sam Kington and Glenn.
  - Functions with prototype '&' had a space between the function and opening peren.
  - Patch to never put spaces around a bare word in braces beginning with ^
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Oct 13 2010 chris@computersalat.de
- noarch pkg
- recreated by cpanspec 1.78
* Wed Jan 20 2010 lars@linux-schulserver.de
- specfile cleanup
* Wed Jan 13 2010 cwh@suse.de
- initial version
